@@ -1,16 +1,99 @@
 from .bitboard import bitPosArray, iterBits, clearBit, firstBit
 from .attack import isAttacked, pinnedOnKing, getAttacks
-from .ldata import fromToRay, moveArray, directions, fileBits, rankBits,\
-    ray45, attack45, ray135, attack135, ray90, attack90, ray00, attack00, FILE, rays
-from pychess.Utils.const import EMPTY, PAWN,\
-    QUEEN, KNIGHT, BISHOP, ROOK, KING, WHITE, BLACK,\
-    SITTUYINCHESS, FISCHERRANDOMCHESS, SUICIDECHESS, GIVEAWAYCHESS, CAMBODIANCHESS,\
-    ATOMICCHESS, WILDCASTLECHESS, WILDCASTLESHUFFLECHESS, CRAZYHOUSECHESS, ASEAN_VARIANTS,\
-    HORDECHESS, PLACEMENTCHESS, BPAWN, sliders,\
-    A8, A6, G6, F6, H1, C3, B2, B3, A3, D6, D8, E3, E1, E8, C7, F2, D1, E6, H3, D3, H2, G7, H6, H7,\
-    ASEAN_QUEEN, ASEAN_BBISHOP, ASEAN_WBISHOP, NORMAL_MOVE, QUEEN_CASTLE, KING_CASTLE, ENPASSANT,\
-    KNIGHT_PROMOTION, BISHOP_PROMOTION, ROOK_PROMOTION, QUEEN_PROMOTION, KING_PROMOTION, NULL_MOVE,\
-    DROP_VARIANTS, DROP, B_OOO, B_OO, W_OOO, W_OO
+from .ldata import (
+    fromToRay,
+    moveArray,
+    directions,
+    fileBits,
+    rankBits,
+    ray45,
+    attack45,
+    ray135,
+    attack135,
+    ray90,
+    attack90,
+    ray00,
+    attack00,
+    FILE,
+    rays,
+)
+from pychess.Utils.const import (
+    EMPTY,
+    PAWN,
+    QUEEN,
+    KNIGHT,
+    BISHOP,
+    ROOK,
+    KING,
+    HAWK,
+    ELEPHANT,
+    WHITE,
+    BLACK,
+    SITTUYINCHESS,
+    FISCHERRANDOMCHESS,
+    SUICIDECHESS,
+    GIVEAWAYCHESS,
+    CAMBODIANCHESS,
+    ATOMICCHESS,
+    WILDCASTLECHESS,
+    WILDCASTLESHUFFLECHESS,
+    CRAZYHOUSECHESS,
+    ASEAN_VARIANTS,
+    HORDECHESS,
+    PLACEMENTCHESS,
+    SCHESS,
+    LIGHTBRIGADECHESS,
+    BPAWN,
+    sliders,
+    A8,
+    A6,
+    G6,
+    F6,
+    H1,
+    C3,
+    B2,
+    B3,
+    A3,
+    D6,
+    D8,
+    E3,
+    E1,
+    E8,
+    C7,
+    F2,
+    D1,
+    E6,
+    H3,
+    D3,
+    H2,
+    G7,
+    H6,
+    H7,
+    ASEAN_QUEEN,
+    ASEAN_BBISHOP,
+    ASEAN_WBISHOP,
+    NORMAL_MOVE,
+    QUEEN_CASTLE,
+    KING_CASTLE,
+    ENPASSANT,
+    KNIGHT_PROMOTION,
+    BISHOP_PROMOTION,
+    ROOK_PROMOTION,
+    QUEEN_PROMOTION,
+    KING_PROMOTION,
+    DROP_VARIANTS,
+    DROP,
+    B_OOO,
+    B_OO,
+    W_OOO,
+    W_OO,
+    HAWK_PROMOTION,
+    ELEPHANT_PROMOTION,
+    HAWK_GATE,
+    ELEPHANT_GATE,
+    HAWK_GATE_AT_ROOK,
+    ELEPHANT_GATE_AT_ROOK,
+)
 
 # The format of a move is as follows - from left:
 # 4 bits:  Descriping the type of the move
@@ -22,14 +105,31 @@ for i in range(64):
     shiftedFromCords.append(i << 6)
 
 shiftedFlags = []
-for i in NORMAL_MOVE, QUEEN_CASTLE, KING_CASTLE, ENPASSANT, \
-        KNIGHT_PROMOTION, BISHOP_PROMOTION, ROOK_PROMOTION, QUEEN_PROMOTION, KING_PROMOTION, NULL_MOVE, DROP:
+for i in (
+    NORMAL_MOVE,
+    QUEEN_CASTLE,
+    KING_CASTLE,
+    ENPASSANT,
+    KNIGHT_PROMOTION,
+    BISHOP_PROMOTION,
+    ROOK_PROMOTION,
+    QUEEN_PROMOTION,
+    KING_PROMOTION,
+    HAWK_PROMOTION,
+    ELEPHANT_PROMOTION,
+    HAWK_GATE,
+    ELEPHANT_GATE,
+    HAWK_GATE_AT_ROOK,
+    ELEPHANT_GATE_AT_ROOK,
+    DROP,
+):
     shiftedFlags.append(i << 12)
 
 
 def newMove(fromcord, tocord, flag=NORMAL_MOVE):
     return shiftedFlags[flag] + shiftedFromCords[fromcord] + tocord
 
+
 # Generate all moves
 
 
@@ -44,53 +144,65 @@ def genCastles(board):
         blocker = clearBit(clearBit(board.blocker, king), rook)
         stepover = fromToRay[king][king_after] | fromToRay[rook][rook_after]
         if not stepover & blocker:
-            for cord in range(
-                    min(king, king_after), max(king, king_after) + 1):
+            for cord in range(min(king, king_after), max(king, king_after) + 1):
                 if isAttacked(board, cord, 1 - color):
                     return
-            if FILE(king) == 3 and board.variant in (WILDCASTLECHESS,
-                                                     WILDCASTLESHUFFLECHESS):
+            if FILE(king) == 3 and board.variant in (
+                WILDCASTLECHESS,
+                WILDCASTLESHUFFLECHESS,
+            ):
                 castle = QUEEN_CASTLE if castle == KING_CASTLE else KING_CASTLE
             if board.variant == FISCHERRANDOMCHESS:
-                return newMove(king, rook, castle)
+                yield newMove(king, rook, castle)
             else:
-                return newMove(king, king_after, castle)
+                yield newMove(king, king_after, castle)
+                if board.variant == SCHESS:
+                    holding = board.holding[color]
+                    if holding[HAWK] == 0 and holding[ELEPHANT] == 0:
+                        return
+                    for king in iterBits(
+                        board.boards[board.color][KING] & board.virgin[board.color]
+                    ):
+                        if holding[HAWK] > 0:
+                            yield newMove(king, king_after, HAWK_GATE)
+                            yield newMove(rook, king, HAWK_GATE_AT_ROOK)
+                        if holding[ELEPHANT] > 0:
+                            yield newMove(king, king_after, ELEPHANT_GATE)
+                            yield newMove(rook, king, ELEPHANT_GATE_AT_ROOK)
 
     king = board.ini_kings[board.color]
-    wildcastle = FILE(king) == 3 and board.variant in (WILDCASTLECHESS,
-                                                       WILDCASTLESHUFFLECHESS)
+    wildcastle = FILE(king) == 3 and board.variant in (
+        WILDCASTLECHESS,
+        WILDCASTLESHUFFLECHESS,
+    )
     if board.color == WHITE:
         if board.castling & W_OO:
             side = 0 if wildcastle else 1
-            move = generateOne(WHITE, side, board.fin_kings[WHITE][side],
-                               board.fin_rooks[WHITE][side])
-            if move:
-                yield move
+            yield from generateOne(
+                WHITE, side, board.fin_kings[WHITE][side], board.fin_rooks[WHITE][side]
+            )
 
         if board.castling & W_OOO:
             side = 1 if wildcastle else 0
-            move = generateOne(WHITE, side, board.fin_kings[WHITE][side],
-                               board.fin_rooks[WHITE][side])
-            if move:
-                yield move
+            yield from generateOne(
+                WHITE, side, board.fin_kings[WHITE][side], board.fin_rooks[WHITE][side]
+            )
     else:
         if board.castling & B_OO:
             side = 0 if wildcastle else 1
-            move = generateOne(BLACK, side, board.fin_kings[BLACK][side],
-                               board.fin_rooks[BLACK][side])
-            if move:
-                yield move
+            yield from generateOne(
+                BLACK, side, board.fin_kings[BLACK][side], board.fin_rooks[BLACK][side]
+            )
 
         if board.castling & B_OOO:
             side = 1 if wildcastle else 0
-            move = generateOne(BLACK, side, board.fin_kings[BLACK][side],
-                               board.fin_rooks[BLACK][side])
-            if move:
-                yield move
+            yield from generateOne(
+                BLACK, side, board.fin_kings[BLACK][side], board.fin_rooks[BLACK][side]
+            )
 
 
 def genPieceMoves(board, piece, tcord):
-    """"
+    """ "
     Used by parseSAN only to accelerate it a bit
     """
     moves = set()
@@ -107,8 +219,9 @@ def genPieceMoves(board, piece, tcord):
     if piece == BISHOP:
         bishops = board.boards[board.color][BISHOP]
         if board.variant in ASEAN_VARIANTS:
-            bishopMoves = moveArray[ASEAN_WBISHOP if board.color == WHITE else
-                                    ASEAN_BBISHOP]
+            bishopMoves = moveArray[
+                ASEAN_WBISHOP if board.color == WHITE else ASEAN_BBISHOP
+            ]
             for fcord in iterBits(bishops):
                 if tcord in iterBits(bishopMoves[fcord] & notfriends):
                     moves.add(newMove(fcord, tcord))
@@ -117,8 +230,10 @@ def genPieceMoves(board, piece, tcord):
             blocker = board.blocker
             for fcord in iterBits(bishops):
                 try:
-                    attackBoard = attack45[fcord][ray45[fcord] & blocker] | \
-                        attack135[fcord][ray135[fcord] & blocker]
+                    attackBoard = (
+                        attack45[fcord][ray45[fcord] & blocker]
+                        | attack135[fcord][ray135[fcord] & blocker]
+                    )
                 except KeyError:
                     attackBoard = 0
                 if tcord in iterBits(attackBoard & notfriends):
@@ -130,8 +245,10 @@ def genPieceMoves(board, piece, tcord):
         rooks = board.boards[board.color][ROOK]
         for fcord in iterBits(rooks):
             try:
-                attackBoard = attack00[fcord][ray00[fcord] & blocker] | \
-                    attack90[fcord][ray90[fcord] & blocker]
+                attackBoard = (
+                    attack00[fcord][ray00[fcord] & blocker]
+                    | attack90[fcord][ray90[fcord] & blocker]
+                )
             except KeyError:
                 attackBoard = 0
             if tcord in iterBits(attackBoard & notfriends):
@@ -159,23 +276,29 @@ def genPieceMoves(board, piece, tcord):
             blocker = board.blocker
             for fcord in iterBits(queens):
                 try:
-                    attackBoard = attack45[fcord][ray45[fcord] & blocker] | \
-                        attack135[fcord][ray135[fcord] & blocker]
+                    attackBoard = (
+                        attack45[fcord][ray45[fcord] & blocker]
+                        | attack135[fcord][ray135[fcord] & blocker]
+                    )
                 except KeyError:
                     attackBoard = 0
                 if tcord in iterBits(attackBoard & notfriends):
                     moves.add(newMove(fcord, tcord))
 
                 try:
-                    attackBoard = attack00[fcord][ray00[fcord] & blocker] | \
-                        attack90[fcord][ray90[fcord] & blocker]
+                    attackBoard = (
+                        attack00[fcord][ray00[fcord] & blocker]
+                        | attack90[fcord][ray90[fcord] & blocker]
+                    )
                 except KeyError:
                     attackBoard = 0
                 if tcord in iterBits(attackBoard & notfriends):
                     moves.add(newMove(fcord, tcord))
             return moves
 
-    if (board.variant == SUICIDECHESS or board.variant == GIVEAWAYCHESS) and piece == KING:
+    if (
+        board.variant == SUICIDECHESS or board.variant == GIVEAWAYCHESS
+    ) and piece == KING:
         kings = board.boards[board.color][KING]
         if kings:
             kingMoves = moveArray[KING]
@@ -190,6 +313,7 @@ def genPieceMoves(board, piece, tcord):
 
 def gen_sittuyin_promotions(board):
     from pychess.Variants import variants
+
     blocker = board.blocker
     notblocker = ~blocker
 
@@ -207,21 +331,25 @@ def gen_sittuyin_promotions(board):
         if board.pieceCount[board.color][PAWN] == 1 or cord in promotion_zone:
             # in place promotions
             move = newMove(cord, cord, QUEEN_PROMOTION)
-            if not board.willGiveCheck(move) and not willDirectAttack(board, move, cord):
+            if not board.willGiveCheck(move) and not willDirectAttack(
+                board, move, cord
+            ):
                 yield move
 
             # queen move promotion
             for c in iterBits(queenMoves[cord] & notblocker):
                 move = newMove(cord, c, QUEEN_PROMOTION)
-                if not board.willGiveCheck(move) and not willDirectAttack(board, move, c):
+                if not board.willGiveCheck(move) and not willDirectAttack(
+                    board, move, c
+                ):
                     yield move
 
 
 def genAllMoves(board, drops=True):
     from pychess.Variants import variants
-    if drops and board.variant in DROP_VARIANTS:
-        for move in genDrops(board):
-            yield move
+
+    if drops and board.variant in DROP_VARIANTS and board.variant != SCHESS:
+        yield from genDrops(board)
 
     # In sittuyin you have to place your pieces before any real move
     if board.variant == SITTUYINCHESS or board.variant == PLACEMENTCHESS:
@@ -242,18 +370,32 @@ def genAllMoves(board, drops=True):
     rooks = board.boards[board.color][ROOK]
     queens = board.boards[board.color][QUEEN]
     kings = board.boards[board.color][KING]
+    hawks = board.boards[board.color][HAWK]
+    elephants = board.boards[board.color][ELEPHANT]
 
     PROMOTIONS = variants[board.variant].PROMOTIONS
     # In sittuyin only one queen allowed to exist any time per side
     if board.variant == SITTUYINCHESS and queens:
-        PROMOTIONS = (NORMAL_MOVE, )
+        PROMOTIONS = (NORMAL_MOVE,)
+    elif board.variant == LIGHTBRIGADECHESS:
+        PROMOTIONS = (QUEEN_PROMOTION,) if board.color == WHITE else (KNIGHT_PROMOTION,)
 
-    # Knights
+    # Knights, Hawks, Elephants
     knightMoves = moveArray[KNIGHT]
-    for cord in iterBits(knights):
+    for cord in iterBits(knights | hawks | elephants):
         for c in iterBits(knightMoves[cord] & notfriends):
             yield newMove(cord, c)
 
+    # knight moves with gating
+    holding = board.holding[board.color]
+    if board.variant == SCHESS and (holding[HAWK] > 0 or holding[ELEPHANT] > 0):
+        for cord in iterBits(knights & board.virgin[board.color]):
+            for c in iterBits(knightMoves[cord] & notfriends):
+                if holding[HAWK] > 0:
+                    yield newMove(cord, c, HAWK_GATE)
+                if holding[ELEPHANT] > 0:
+                    yield newMove(cord, c, ELEPHANT_GATE)
+
     # King
     if kings:
         kingMoves = moveArray[KING]
@@ -265,13 +407,23 @@ def genAllMoves(board, drops=True):
                         yield newMove(cord, c)
                 else:
                     yield newMove(cord, c)
+                    if board.variant == SCHESS and (
+                        holding[HAWK] > 0 or holding[ELEPHANT] > 0
+                    ):
+                        for cord in iterBits(kings & board.virgin[board.color]):
+                            if holding[HAWK] > 0:
+                                yield newMove(cord, c, HAWK_GATE)
+                            if holding[ELEPHANT] > 0:
+                                yield newMove(cord, c, ELEPHANT_GATE)
 
     if board.variant in ASEAN_VARIANTS:
         # Rooks
         for cord in iterBits(rooks):
             try:
-                attackBoard = attack00[cord][ray00[cord] & blocker] | \
-                    attack90[cord][ray90[cord] & blocker]
+                attackBoard = (
+                    attack00[cord][ray00[cord] & blocker]
+                    | attack90[cord][ray90[cord] & blocker]
+                )
             except KeyError:
                 attackBoard = 0
             for c in iterBits(attackBoard & notfriends):
@@ -284,45 +436,78 @@ def genAllMoves(board, drops=True):
                 yield newMove(cord, c)
 
         # Bishops
-        bishopMoves = moveArray[ASEAN_WBISHOP if board.color == WHITE else
-                                ASEAN_BBISHOP]
+        bishopMoves = moveArray[
+            ASEAN_WBISHOP if board.color == WHITE else ASEAN_BBISHOP
+        ]
         for cord in iterBits(bishops):
             for c in iterBits(bishopMoves[cord] & notfriends):
                 yield newMove(cord, c)
 
     else:
-        # Rooks and Queens
-        for cord in iterBits(rooks | queens):
+        # Rooks and Queens and Elephants
+        for cord in iterBits(rooks | queens | elephants):
             try:
-                attackBoard = attack00[cord][ray00[cord] & blocker] | \
-                    attack90[cord][ray90[cord] & blocker]
+                attackBoard = (
+                    attack00[cord][ray00[cord] & blocker]
+                    | attack90[cord][ray90[cord] & blocker]
+                )
             except KeyError:
                 attackBoard = 0
             for c in iterBits(attackBoard & notfriends):
                 yield newMove(cord, c)
 
-    # Bishops and Queens
-        for cord in iterBits(bishops | queens):
+        if board.variant == SCHESS and (holding[HAWK] > 0 or holding[ELEPHANT] > 0):
+            for cord in iterBits((rooks | queens) & board.virgin[board.color]):
+                try:
+                    attackBoard = (
+                        attack00[cord][ray00[cord] & blocker]
+                        | attack90[cord][ray90[cord] & blocker]
+                    )
+                except KeyError:
+                    attackBoard = 0
+                for c in iterBits(attackBoard & notfriends):
+                    if holding[HAWK] > 0:
+                        yield newMove(cord, c, HAWK_GATE)
+                    if holding[ELEPHANT] > 0:
+                        yield newMove(cord, c, ELEPHANT_GATE)
+
+        # Bishops and Queens, Hawks
+        for cord in iterBits(bishops | queens | hawks):
             try:
-                attackBoard = attack45[cord][ray45[cord] & blocker] | \
-                    attack135[cord][ray135[cord] & blocker]
+                attackBoard = (
+                    attack45[cord][ray45[cord] & blocker]
+                    | attack135[cord][ray135[cord] & blocker]
+                )
             except KeyError:
                 attackBoard = 0
             for c in iterBits(attackBoard & notfriends):
                 yield newMove(cord, c)
 
+        if board.variant == SCHESS and (holding[HAWK] > 0 or holding[ELEPHANT] > 0):
+            for cord in iterBits((bishops | queens) & board.virgin[board.color]):
+                try:
+                    attackBoard = (
+                        attack45[cord][ray45[cord] & blocker]
+                        | attack135[cord][ray135[cord] & blocker]
+                    )
+                except KeyError:
+                    attackBoard = 0
+                for c in iterBits(attackBoard & notfriends):
+                    if holding[HAWK] > 0:
+                        yield newMove(cord, c, HAWK_GATE)
+                    if holding[ELEPHANT] > 0:
+                        yield newMove(cord, c, ELEPHANT_GATE)
+
     # White pawns
     pawnEnemies = enemies | (enpassant is not None and bitPosArray[enpassant] or 0)
     if board.color == WHITE:
-
         # One step
 
         if board.variant == SITTUYINCHESS:
             promotion_zone = []
         else:
             promotion_zone = variants[board.variant].PROMOTION_ZONE[WHITE]
-        movedpawns = (pawns >>
-                      8) & notblocker  # Move all pawns one step forward
+        movedpawns = (pawns >> 8) & notblocker  # Move all pawns one step forward
         for cord in iterBits(movedpawns):
             if cord in promotion_zone:
                 for p in PROMOTIONS:
@@ -333,20 +518,16 @@ def genAllMoves(board, drops=True):
         # Two steps
 
         seccondrow = pawns & rankBits[1]  # Get seccond row pawns
-        movedpawns = (seccondrow >>
-                      8) & notblocker  # Move two steps forward, while
-        movedpawns = (movedpawns >>
-                      8) & notblocker  # ensuring middle cord is clear
+        movedpawns = (seccondrow >> 8) & notblocker  # Move two steps forward, while
+        movedpawns = (movedpawns >> 8) & notblocker  # ensuring middle cord is clear
         for cord in iterBits(movedpawns):
             yield newMove(cord - 16, cord)
 
         # In horde white pawns on first rank may move two squares also
         if board.variant == HORDECHESS:
             firstrow = pawns & rankBits[0]  # Get first row pawns
-            movedpawns = (firstrow >>
-                          8) & notblocker  # Move two steps forward, while
-            movedpawns = (movedpawns >>
-                          8) & notblocker  # ensuring middle cord is clear
+            movedpawns = (firstrow >> 8) & notblocker  # Move two steps forward, while
+            movedpawns = (movedpawns >> 8) & notblocker  # ensuring middle cord is clear
             for cord in iterBits(movedpawns):
                 yield newMove(cord - 16, cord)
 
@@ -378,7 +559,6 @@ def genAllMoves(board, drops=True):
 
     # Black pawns
     else:
-
         # One step
 
         if board.variant == SITTUYINCHESS:
@@ -386,7 +566,7 @@ def genAllMoves(board, drops=True):
         else:
             promotion_zone = variants[board.variant].PROMOTION_ZONE[BLACK]
         movedpawns = (pawns << 8) & notblocker
-        movedpawns &= 0xffffffffffffffff  # contrain to 64 bits
+        movedpawns &= 0xFFFFFFFFFFFFFFFF  # contrain to 64 bits
         for cord in iterBits(movedpawns):
             if cord in promotion_zone:
                 for p in PROMOTIONS:
@@ -431,13 +611,14 @@ def genAllMoves(board, drops=True):
 
     # Sittuyin promotions
     if board.variant == SITTUYINCHESS and pawns and not queens:
-        for move in gen_sittuyin_promotions(board):
-            yield move
+        yield from gen_sittuyin_promotions(board)
 
     # Cambodian extra first moves for king and queen
     if board.variant == CAMBODIANCHESS:
-        if board.arBoard[board.ini_kings[board.color]] == KING and \
-                board.is_first_move[KING][board.color]:
+        if (
+            board.arBoard[board.ini_kings[board.color]] == KING
+            and board.is_first_move[KING][board.color]
+        ):
             if board.color == WHITE:
                 if not board.arBoard[B2]:
                     yield newMove(D1, B2)
@@ -448,8 +629,10 @@ def genAllMoves(board, drops=True):
                     yield newMove(E8, C7)
                 if not board.arBoard[G7]:
                     yield newMove(E8, G7)
-        if board.arBoard[board.ini_queens[board.color]] == QUEEN and \
-                board.is_first_move[QUEEN][board.color]:
+        if (
+            board.arBoard[board.ini_queens[board.color]] == QUEEN
+            and board.is_first_move[QUEEN][board.color]
+        ):
             if board.color == WHITE:
                 if not board.arBoard[E3]:
                     yield newMove(E1, E3)
@@ -459,8 +642,8 @@ def genAllMoves(board, drops=True):
 
     # Castling
     if kings:
-        for move in genCastles(board):
-            yield move
+        yield from genCastles(board)
+
 
 ################################################################################
 #   Generate capturing moves                                                   #
@@ -481,15 +664,19 @@ def genCaptures(board):
     rooks = board.boards[board.color][ROOK]
     queens = board.boards[board.color][QUEEN]
     kings = board.boards[board.color][KING]
+    hawks = board.boards[board.color][HAWK]
+    elephants = board.boards[board.color][ELEPHANT]
 
     PROMOTIONS = variants[board.variant].PROMOTIONS
     # In sittuyin promotion can't give capture
     if board.variant == SITTUYINCHESS:
-        PROMOTIONS = (NORMAL_MOVE, )
+        PROMOTIONS = (NORMAL_MOVE,)
+    elif board.variant == LIGHTBRIGADECHESS:
+        PROMOTIONS = (QUEEN_PROMOTION,) if board.color == WHITE else (KNIGHT_PROMOTION,)
 
     # Knights
     knightMoves = moveArray[KNIGHT]
-    for cord in iterBits(knights):
+    for cord in iterBits(knights | hawks | elephants):
         for c in iterBits(knightMoves[cord] & enemies):
             yield newMove(cord, c)
 
@@ -506,17 +693,21 @@ def genCaptures(board):
     if board.variant in ASEAN_VARIANTS:
         for cord in iterBits(rooks):
             try:
-                attackBoard = attack00[cord][ray00[cord] & blocker] | \
-                    attack90[cord][ray90[cord] & blocker]
+                attackBoard = (
+                    attack00[cord][ray00[cord] & blocker]
+                    | attack90[cord][ray90[cord] & blocker]
+                )
             except KeyError:
                 attackBoard = 0
             for c in iterBits(attackBoard & enemies):
                 yield newMove(cord, c)
     else:
-        for cord in iterBits(rooks | queens):
+        for cord in iterBits(rooks | queens | elephants):
             try:
-                attackBoard = attack00[cord][ray00[cord] & blocker] | \
-                    attack90[cord][ray90[cord] & blocker]
+                attackBoard = (
+                    attack00[cord][ray00[cord] & blocker]
+                    | attack90[cord][ray90[cord] & blocker]
+                )
             except KeyError:
                 attackBoard = 0
             for c in iterBits(attackBoard & enemies):
@@ -524,8 +715,9 @@ def genCaptures(board):
 
     # Bishops and Queens
     if board.variant in ASEAN_VARIANTS:
-        bishopMoves = moveArray[ASEAN_WBISHOP if board.color == WHITE else
-                                ASEAN_BBISHOP]
+        bishopMoves = moveArray[
+            ASEAN_WBISHOP if board.color == WHITE else ASEAN_BBISHOP
+        ]
         for cord in iterBits(bishops):
             for c in iterBits(bishopMoves[cord] & enemies):
                 yield newMove(cord, c)
@@ -534,10 +726,12 @@ def genCaptures(board):
             for c in iterBits(queenMoves[cord] & enemies):
                 yield newMove(cord, c)
     else:
-        for cord in iterBits(bishops | queens):
+        for cord in iterBits(bishops | queens | hawks):
             try:
-                attackBoard = attack45[cord][ray45[cord] & blocker] | \
-                    attack135[cord][ray135[cord] & blocker]
+                attackBoard = (
+                    attack45[cord][ray45[cord] & blocker]
+                    | attack135[cord][ray135[cord] & blocker]
+                )
             except KeyError:
                 attackBoard = 0
             for c in iterBits(attackBoard & enemies):
@@ -609,6 +803,7 @@ def genCaptures(board):
             else:
                 yield newMove(cord + 9, cord)
 
+
 ################################################################################
 #   Generate escapes from check                                                #
 ################################################################################
@@ -616,6 +811,7 @@ def genCaptures(board):
 
 def genCheckEvasions(board):
     from pychess.Variants import variants
+
     color = board.color
     opcolor = 1 - color
 
@@ -627,11 +823,14 @@ def genCheckEvasions(board):
 
     arBoard = board.arBoard
     if bin(checkers).count("1") == 1:
-
         PROMOTIONS = variants[board.variant].PROMOTIONS
         # In sittuyin promotion move not allowed to capture opponent pieces
         if board.variant == SITTUYINCHESS and board.boards[board.color][QUEEN]:
-            PROMOTIONS = (NORMAL_MOVE, )
+            PROMOTIONS = (NORMAL_MOVE,)
+        elif board.variant == LIGHTBRIGADECHESS:
+            PROMOTIONS = (
+                (QUEEN_PROMOTION,) if board.color == WHITE else (KNIGHT_PROMOTION,)
+            )
         promotion_zone = variants[board.variant].PROMOTION_ZONE[color]
 
         # Captures of checking pieces (except by king, which we will test later)
@@ -639,7 +838,11 @@ def genCheckEvasions(board):
         b = getAttacks(board, chkcord, color) & ~kings
         for cord in iterBits(b):
             if not pinnedOnKing(board, cord, color):
-                if arBoard[cord] == PAWN and chkcord in promotion_zone and board.variant != SITTUYINCHESS:
+                if (
+                    arBoard[cord] == PAWN
+                    and chkcord in promotion_zone
+                    and board.variant != SITTUYINCHESS
+                ):
                     for p in PROMOTIONS:
                         yield newMove(cord, chkcord, p)
                 else:
@@ -666,15 +869,21 @@ def genCheckEvasions(board):
                 if color == WHITE and cord > H2:
                     if bitPosArray[cord - 8] & pawns:
                         b |= bitPosArray[cord - 8]
-                    if cord >> 3 == 3 and arBoard[cord - 8] == EMPTY and \
-                            bitPosArray[cord - 16] & pawns:
+                    if (
+                        cord >> 3 == 3
+                        and arBoard[cord - 8] == EMPTY
+                        and bitPosArray[cord - 16] & pawns
+                    ):
                         b |= bitPosArray[cord - 16]
 
                 elif color == BLACK and cord < H7:
                     if bitPosArray[cord + 8] & pawns:
                         b |= bitPosArray[cord + 8]
-                    if cord >> 3 == 4 and arBoard[cord + 8] == EMPTY and \
-                            bitPosArray[cord + 16] & pawns:
+                    if (
+                        cord >> 3 == 4
+                        and arBoard[cord + 8] == EMPTY
+                        and bitPosArray[cord + 16] & pawns
+                    ):
                         b |= bitPosArray[cord + 16]
 
                 for fcord in iterBits(b):
@@ -698,6 +907,7 @@ def genCheckEvasions(board):
 
                 if board.variant == SITTUYINCHESS and pawns and not queens:
                     from .lmove import TCORD
+
                     for move in gen_sittuyin_promotions(board):
                         if TCORD(move) == cord:
                             yield move
@@ -758,7 +968,10 @@ def genDrops(board):
 
                         if holding[BISHOP] == 2 and piece != BISHOP:
                             # occupying all same colored fields before any bishop dropped is no-no
-                            if occupied_colors[WHITE] == 4 or occupied_colors[BLACK] == 4:
+                            if (
+                                occupied_colors[WHITE] == 4
+                                or occupied_colors[BLACK] == 4
+                            ):
                                 continue
                         elif holding[BISHOP] == 1:
                             for i, baseline_piece in enumerate(base_line):
@@ -766,7 +979,10 @@ def genDrops(board):
                                     first_bishop_cord = i
                                     break
                             # occupying all possible place of opp colored bishop is no-no
-                            if piece != BISHOP and occupied_colors[1 - first_bishop_cord % 2] == 4:
+                            if (
+                                piece != BISHOP
+                                and occupied_colors[1 - first_bishop_cord % 2] == 4
+                            ):
                                 continue
                             # same colored bishop is no-no
                             elif piece == BISHOP and first_bishop_cord % 2 == cord % 2:
